#
# spec file for package pdfarranger
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2020 Karl Cheng <qantas94heavy@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pdfarranger
Version:        1.9.2
Release:        bp155.1.5
Summary:        Merge, split, rotate, crop, and rearrange pages of PDF documents
License:        GPL-3.0-only
URL:            https://github.com/pdfarranger/pdfarranger
Source:         https://github.com/pdfarranger/pdfarranger/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  python3-devel
BuildRequires:  python3-distutils-extra
BuildRequires:  python3-rpm-macros
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       gtk3
Requires:       python3-cairo
Requires:       python3-dateutil >= 2.4.0
Requires:       python3-gobject-Gdk
Requires:       python3-pikepdf >= 2.8.0
Requires:       typelib-1_0-Gtk-3_0
Requires:       typelib-1_0-Poppler-0_18
Recommends:     python3-img2pdf >= 0.3.4
BuildArch:      noarch

%description
pdfarranger is a small python-gtk application, which helps the user
to merge or split pdf documents and rotate, crop and rearrange their
pages using a graphical interface. It is a frontend for pikepdf.

pdfarranger is a fork of Konstantinos Poulios’s pdfshuffler. It is
a humble attempt to make the project a bit more active.

%lang_package

%prep
%autosetup -p1

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
%suse_update_desktop_file -r com.github.jeromerobert.pdfarranger Graphics VectorGraphics
%find_lang %{name} %{?no_lang_C}
%fdupes -s %{buildroot}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}-py%{python3_version}.egg-info
%{_datadir}/applications/com.github.jeromerobert.pdfarranger.desktop
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/%{name}
%{_datadir}/icons/hicolor
%{_datadir}/metainfo/com.github.jeromerobert.pdfarranger.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Tue Nov 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.9.2
  * Fix "export all to individual files" overwrite
  * Fix unexpected application close and quit
  * Fix buggy export when CropBox is larger than MediaBox
  * Fix equal page size test in generate booklet
  * Fix NAME in man page
  * Some translation fixes
* Wed Oct 12 2022 C J <c.j@tuta.io>
- Update to 1.9.1:
  * Support for PikePDF 6 and so qpdf 11 (#716)
  * Fix a bug in booklet creation (#720)
  * Some translation update
- Version 1.9.0
  * Many improvements and fixes in the icon view (#505, #506, #612,
    [#629], #632, #637, #654, #670)
  * Remember previous file chooser location (#508)
  * Add close and open actions (#581, #593, #597)
  * Increase I/O performance and responsiveness (#542, #623)
  * Add option to set language in Windows (#578)
  * Add support for pasting an image from clipboard (#675)
  * Pan the view when pressing mouse wheel and moving mouse (#677)
  * Add fullscreen mode (#665)
  * Allow to print the document (#647)
  * Require GTK >= 3.20 because of a new file chooser on Windows
    (#704)
  * State that pikepdf 6 is not yet supported (#716)
* Tue Sep 13 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add missing typelib-1_0-Gtk-3_0 requirement
* Sun Mar 20 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.8.2:
  * Fix 2 bugs in scaled pages export
* Mon Dec 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.8.1
  * Fix transformation (rotation, crop, split, ...) of duplicated
    pages
  * Fix some UI glitches
  * Update some translations
  * Set minimum pikepdf version to 1.17.0
  * Fix import of PDF with CropBox
  * Fix clipboard on Wayland
  * Remember window position on screen
  * Fix error with annotations on duplicated pages
* Mon Apr 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.7.1
  * Fix "TypeError: only pages can be inserted" with
    libqpdf >= 10.2.0 & pikepdf < 2.7.0
  * Display imported files in alphabetical order
  * Release memory after rendering and deleting pages
  * Installation instructions for FreeBSD
  * Fix a segfault on "crop white borders" while rendering thumbnails
  * Allow PDF Arranger to be recognized as a handler for all image
    MIME type that it can handle
  * Fix min & max zoom level limits
  * Fix issue with pages copied with ctrl + dnd
  * Fix displayed page range when using paste before
* Mon Feb  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.7.0
  * Allow to edit Keywords, Subjects and dates in document info
  * Ctrl+click now remove a single page from the selection
  * Allow selection of odd or even pages
  * Add option to crop white borders
  * Allow export to individual files
  * Enable autoscroll when rubberband selecting
  * Display the current selection in the status bar
  * Fix import of images with alpha channel
  * Allow to scroll the view with up/down & page up/down keys
  * Allow to zoom to full page
  * Add option to select all pages from same file
  * Fix visual issue in dialogs
  * Improve responsiveness when scrolling zoom levels
  * Change behavior when selecting with shift + click
  * Select a continuous range when drag-selecting
  * Add page scaling
  * Allow to customize keyboard shortcut from the configuration file
  * Add option to select all pages with the same page format
  * Add 'new' button to open new document
  * Support import of encrypted PDF file
  * Allow to insert blank pages
  * Split Page now support n x m split instead of just 1 x 2
  * Reduce memory usage
  * Fix the shortcut created by the Windows MSI installer
  * Problems with editing if not saving after each operation
  * Fix slow paste-interleave-odd/even
* Fri Aug 28 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.6.2. Changes since version 1.5.3:
  * Remove an invalid key from the .desktop file
  * Fix empty string support in the property editor
  * Grey out paste actions if nothing is in the clipboard
  * Improve iconview look and feel
  * Support image file import
  * Ask user confirmation before quit
  * New application icon
  * Insert pages of a PDF at drop location
  * Support page drag and drop on Windows
  * Support Copy/Paste from a file explorer
  * Recommend pikepdf >= 1.15.1
  * Update some translations
- Update description
* Sun Apr 19 2020 Karl Cheng <qantas94heavy@gmail.com>
- Initial build of version 1.5.3
